@@ -180,7 +180,7 @@ def _load_metadata(file = 'metadata.yml', local_data_root = None, remote_data_ro
     value passed to this function will override the value provided in the file.
     If both are unspecified, it is assumed that no remote data store exists.
 
-    The "data_dir" property must be provided for every data set in ``file`` and
+    The "data_dir" property is optional for every data set in ``file`` and
     specifies the directory on the local system containing the data files.
     "data_dir" may be an absolute path or a relative path with respect to
     ``local_data_root``. If it is a relative path, it will be converted to an
@@ -294,7 +294,7 @@ def _defaults_for_key(key):
         # - if it is a relative path, it will be interpreted by _load_metadata
         #   as relative to local_data_root and will be converted to an absolute
         #   path
-        'data_dir': None,
+        'data_dir': '.',
 
         # the path of the directory containing the data on a remote server
         # - this may be a full URL or a relative path, or None if there exists
@@ -332,10 +332,19 @@ def _defaults_for_key(key):
         # list of labels for epoch encoder
         'epoch_encoder_possible_labels': ['Type 1', 'Type 2', 'Type 3'],
 
-        # list of dicts giving name, channel, units, amplitude window, epoch window for each unit
-        # - e.g. [{'name': 'Unit X', 'channel': 'Channel A', 'units': 'uV', 'amplitude': [75, 150], 'epoch': 'Type 1'}, ...]
+        # list of dicts giving name, channel, units, amplitude window, epoch window, color for each unit
+        # - e.g. [{'name': 'Unit X', 'channel': 'Channel A', 'units': 'uV', 'amplitude': [75, 150], 'epoch': 'Type 1', 'color': 'ff0000'}, ...]
         'amplitude_discriminators': None,
 
+        # list of dicts giving name of a spiketrain, start and stop firing rate
+        # thresholds in Hz for each burst
+        # - 'spiketrain' is required and used to find the appropriate spike
+        #   train by name, whereas 'name' is option and is used to name the
+        #   Epoch generated by load_dataset, defaults to the spiketrain's name
+        #   with ' burst' appended
+        # - e.g. [{'spiketrain': 'Unit X', 'name': 'Unit X burst', 'thresholds': [10, 8]}, ...]
+        'burst_detectors': None,
+
         # the output file of a tridesclous spike sorting analysis
         # - path relative to data_dir and remote_data_dir
         'tridesclous_file': None,
@@ -381,6 +390,15 @@ def _defaults_for_key(key):
 
         # amount of time in seconds to plot initially
         't_width': 40,
+
+        # factor to subtract from each signal before rectification when
+        # calculating rectified area under the curve (RAUC)
+        # - can be None, 'mean', or 'median'
+        'rauc_baseline': None,
+
+        # width of bins in seconds used for calculating rectified area under
+        # the curve (RAUC) for signals
+        'rauc_bin_duration': 0.1,
     }
 
     return defaults
